<template>
  <ContentScrollView :paddingH="false">
    <nut-form :model-value="form" ref="formRef" :rules="rules">
      <nut-form-item label="头像:" class="bole-form-item" prop="avatarUrl">
        <Uploader v-model:file-list="form.avatarUrl" :maximum="1" class="bole-uploader"> </Uploader>
      </nut-form-item>
      <nut-form-item
        label="企业名称:"
        class="bole-form-item"
        prop="enterpriseName"
        :required="hasEnterpriseName"
      >
        <nut-input
          v-model.trim="form.enterpriseName"
          class="nut-input-text bole-input-text"
          placeholder="请输入企业名称"
          type="text"
          :max-length="35"
          :disabled="isCompanyAudited || isCertified"
          show-word-limit
        />
      </nut-form-item>
      <nut-form-item label="姓名:" class="bole-form-item" prop="fullName" :required="hasFullName">
        <nut-input
          v-model.trim="form.fullName"
          class="nut-input-text bole-input-text"
          placeholder="请输入姓名"
          type="text"
          :max-length="10"
          show-word-limit
        />
      </nut-form-item>
      <nut-form-item label="性别:" class="bole-form-item" prop="gender">
        <ChooseInputWithPicker
          v-model="form.gender"
          placeholder="请选择性别"
          :value-enum="GenderText"
        />
      </nut-form-item>
      <nut-form-item label="职称:" class="bole-form-item" prop="positionName">
        <nut-input
          v-model.trim="form.positionName"
          class="nut-input-text bole-input-text"
          placeholder="请输入职称"
          type="text"
          :max-length="15"
          show-word-limit
        />
      </nut-form-item>
      <nut-form-item label="手机号:" class="bole-form-item" prop="phoneNumber">
        <nut-input
          v-model.trim="form.phoneNumber"
          class="nut-input-text bole-input-text"
          placeholder="请输入手机号"
          type="text"
          disabled
        />
      </nut-form-item>
      <nut-form-item label="邮箱:" class="bole-form-item" prop="email">
        <nut-input
          v-model.trim="form.email"
          class="nut-input-text bole-input-text"
          placeholder="请输入邮箱"
          type="text"
          :disabled="isBindEmailAddress"
        />
      </nut-form-item>
      <nut-form-item label="所在地区:" class="bole-form-item" prop="areaList" required>
        <ChooseInputWithAreaPicker
          :columns="areaTreeList"
          v-model="form.areaList"
          placeholder="请选择所在地区"
        ></ChooseInputWithAreaPicker>
      </nut-form-item>
      <nut-form-item label="详细地址:" class="bole-form-item" prop="address">
        <nut-input
          v-model.trim="form.address"
          class="nut-input-text bole-input-text"
          placeholder="请输入详细地址"
          type="text"
          :max-length="20"
          show-word-limit
        />
      </nut-form-item>
      <nut-form-item label="微信二维码:" class="bole-form-item" prop="wxQrcodeUrl">
        <Uploader v-model:file-list="form.wxQrcodeUrl" :maximum="1" class="bole-uploader">
        </Uploader>
      </nut-form-item>
    </nut-form>
  </ContentScrollView>
  <PageFooter :isOnlyAction="false">
    <PageFooterBtn type="primary" @click="handleConfirm">保存</PageFooterBtn>
  </PageFooter>
</template>

<script setup lang="ts">
import { ChooseInputWithPicker, ChooseInputWithAreaPicker } from '@12333/components';
import { FormRules } from '@nutui/nutui-taro/dist/types/__VUE/form/types';
import { useUser, useMyCertificationAuditInfo } from '@/hooks';
import { useAllAreaList } from '@12333/hooks';
import { convertApi2FormUrlOnlyOne, Message, isFileAllUploaded, FormValidator } from '@12333/utils';
import { Gender, GenderText } from '@12333/constants';
import * as userServices from '@12333/services/api/User';
import Taro from '@tarojs/taro';

defineOptions({
  name: 'userInfoInnerPage',
});

const { userDetail, updateUserInfo, isCompanyAudited } = useUser();

const { findAreaNameFromCode, areaTreeList } = useAllAreaList();

const { isCertified } = useMyCertificationAuditInfo();

const isBindEmailAddress = computed(() => {
  return !!userDetail.value?.bindEmailAddress;
});

const form = reactive({
  userName: userDetail.value?.userName ?? '',
  avatarUrl: convertApi2FormUrlOnlyOne(userDetail.value?.originalAvatarUrl),
  enterpriseName: userDetail.value?.customerName ?? '',
  phoneNumber: userDetail.value?.phoneNumber ?? '',
  email: userDetail.value?.userInfoEmailAddress ?? '',
  fullName: userDetail.value?.contacter ?? '',
  gender: userDetail.value?.genderType ?? Gender.Male,
  positionName: userDetail.value?.jobTitle ?? '',
  areaList: [
    userDetail.value.provinceCode,
    userDetail.value.cityCode,
    userDetail.value.countyCode,
  ].filter(Boolean),
  address: userDetail.value?.addressDetail ?? '',
  wxQrcodeUrl: convertApi2FormUrlOnlyOne(userDetail.value?.wxQrCodeUrl),
});

const hasEnterpriseName = computed(() => !!userDetail.value?.customerName);
const hasFullName = computed(() => !!userDetail.value?.contacter);

const rules = computed(() => {
  let _rules: FormRules = {
    areaList: [
      { required: true, validator: FormValidator.validatorArray, message: '请选择所在地区' },
    ],
    email: [{ validator: FormValidator.validatorEmail, message: '请输入正确的邮箱' }],
  };
  if (hasEnterpriseName.value) {
    _rules['enterpriseName'] = [{ required: true, message: '请输入企业名称' }];
  }
  if (hasFullName.value) {
    _rules['fullName'] = [{ required: true, message: '请输入姓名' }];
  }

  return _rules;
});

const formRef = ref<any>(null);

function handleConfirm() {
  if (!formRef.value) return;
  formRef.value.validate().then(({ valid, errors }: any) => {
    if (valid) {
      if (isFileAllUploaded(form.avatarUrl)) {
        handleUpdateUserInfo();
      } else {
        Message.error('存在未上传完成的文件');
      }
    }
  });
}

async function handleUpdateUserInfo() {
  try {
    let params: API.UpdateUserInfoInput = {
      id: userDetail.value.userId,
      userInfoEmailAddress: form.email,
      avatarUrl: form.avatarUrl[0]?.path ?? '',
      genderType: form.gender,
      jobTitle: form.positionName,
      addressDetail: form.address,
      wxQrCodeUrl: form.wxQrcodeUrl[0]?.path ?? '',
      enterpriseName: form.enterpriseName,
      contacter: form.fullName,
    };
    if (form.areaList?.length > 0) {
      params.provinceCode = form.areaList[0];
      params.cityCode = form.areaList[1];
      params.countyCode = form.areaList[2];
      params.provinceName = findAreaNameFromCode(form.areaList[0]);
      params.cityName = findAreaNameFromCode(form.areaList[1]);
      params.countyName = findAreaNameFromCode(form.areaList[2]);
    }
    let res = await userServices.updateUserInfo(params);
    if (res) {
      Message.success('更新成功', {
        onClosed: () => {
          Taro.navigateBack({
            delta: 1,
          });
        },
      });
      updateUserInfo();
    }
  } catch (error) {}
}
</script>

<style lang="scss">
@import '@/styles/common.scss';
</style>
